@@ -25,6 +25,8 @@
  *
  */
 
+#define GNOME_PRINT_UNSTABLE_API
+
 #include <config.h>
 
 #include <time.h>
@@ -486,6 +488,7 @@ gnome_print_dialog_construct_range_page (GnomePrintDialog *gpd, gint flags, gint
 		a = gtk_adjustment_new (start, start, end, 1, 10, 10);
 		g_object_set_data (G_OBJECT (hbox), "from", a);
 		sb = gtk_spin_button_new (GTK_ADJUSTMENT (a), 1, 0.0);
+		gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (sb), TRUE);
 		gtk_widget_show (sb);
 		gtk_box_pack_start (GTK_BOX (hbox), sb, FALSE, FALSE, 0);
 		gtk_label_set_mnemonic_widget ((GtkLabel *) l, sb);
@@ -510,6 +513,7 @@ gnome_print_dialog_construct_range_page (GnomePrintDialog *gpd, gint flags, gint
 		a = gtk_adjustment_new (end, start, end, 1, 10, 10);
 		g_object_set_data (G_OBJECT (hbox), "to", a);
 		sb = gtk_spin_button_new (GTK_ADJUSTMENT (a), 1, 0.0);
+		gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (sb), TRUE);
 		gtk_widget_show (sb);
 		gtk_box_pack_start (GTK_BOX (hbox), sb, FALSE, FALSE, 0);
 		gtk_label_set_mnemonic_widget ((GtkLabel *) l, sb);
@@ -693,4 +697,24 @@ gnome_print_dialog_get_config (GnomePrintDialog *gpd)
 }
 
 
+/**
+ * gnome_print_dialog_run:
+ * @dialog: 
+ * 
+ * Runs a gnome-print dialog. Use it instead of gtk_dialog_run
+ * in the future this function will handle more stuff like opening
+ * a file selector when printing to a file.
+ * 
+ * Return Value: the user response
+ **/
+gint
+gnome_print_dialog_run (GnomePrintDialog *dialog)
+{
+	gint response;
+
+	response = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+
+	return response;
+}
 
